==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/item/rgss/Game_Party_initialize.rb <==
#==============================================================================
#  Game_Party_initialize.rb
#------------------------------------------------------------------------------
# p[eB̎͑܂Ƃ
# [IɃobNpbNiItem_InfinitỹReij
#==============================================================================

class Game_Party
  attr_reader :backpack

  #--------------------------------------------------------------------------
  #  IuWFNg
  #--------------------------------------------------------------------------
  alias dq_original_initialize initialize
  def initialize
    dq_original_initialize

    # obNpbN̍쐬
    @backpack = Game_Item.new
    @backpack.container = Item_Infinity_Container.new
  end
  #--------------------------------------------------------------------------
  #  ACȅ擾
  #     id : ACe ID
  #--------------------------------------------------------------------------
  def item_number(id)
    count = @backpack.item_count_id(id,Game_Item)
    actors.each do |actor|
      count += actor.backpack.item_count_id(id,Game_Item)
    end
    return count
  end
  #--------------------------------------------------------------------------
  #  ̏擾
  #     id :  ID
  #--------------------------------------------------------------------------
  def weapon_number(id)
    count = @backpack.item_count_id(id,Game_Weapon)
    actors.each do |actor|
      count += actor.backpack.item_count_id(id,Game_Weapon)
    end
    return count
  end
  #--------------------------------------------------------------------------
  #  h̏擾
  #     id : h ID
  #--------------------------------------------------------------------------
  def armor_number(id)
    count = @backpack.item_count_id(id,Game_Armor)
    actors.each do |actor|
      count += actor.backpack.item_count_id(id,Game_Armor)
    end
    return count
  end
  #--------------------------------------------------------------------------
  #  ACȇ ()
  #     id : ACe ID
  #     n  : 
  #--------------------------------------------------------------------------
  def gain_item(id, n)
    Item_Facade.gain_item(id,n,self)
  end
  #--------------------------------------------------------------------------
  #  ̑ ()
  #     id :  ID
  #     n  : 
  #--------------------------------------------------------------------------
  def gain_weapon(id, n)
    Item_Facade.gain_weapon(id,n,self)
  end
  #--------------------------------------------------------------------------
  #  h̑ ()
  #     armor_id : h ID
  #     n        : 
  #--------------------------------------------------------------------------
  def gain_armor(id, n)
    Item_Facade.gain_armor(id,n,self)
  end
  #--------------------------------------------------------------------------
  #  ACě
  #     item_id : ACe ID
  #     n       : 
  #--------------------------------------------------------------------------
  def lose_item(item_id, n)
    # lt] gain_item Ă
    gain_item(item_id, -n)
  end
  #--------------------------------------------------------------------------
  #  ̌
  #     weapon_id :  ID
  #     n         : 
  #--------------------------------------------------------------------------
  def lose_weapon(weapon_id, n)
    # lt] gain_weapon Ă
    gain_weapon(weapon_id, -n)
  end
  #--------------------------------------------------------------------------
  #  ȟ
  #     armor_id : h ID
  #     n        : 
  #--------------------------------------------------------------------------
  def lose_armor(armor_id, n)
    # lt] gain_armor Ă
    gain_armor(armor_id, -n)
  end
  #--------------------------------------------------------------------------
  #  ACe̎gp\
  #     item_id : ACe ID
  #--------------------------------------------------------------------------
  def item_can_use?(item_id)
    # ACě 0 ̏ꍇ
    if item_number(item_id) == 0
      # gps\
      return false
    end
    # gp\擾
    occasion = $data_items[item_id].occasion
    # og̏ꍇ
    if $game_temp.in_battle
      # gp\ 0 (펞) ܂ 1 (oĝ) Ȃgp\
      return (occasion == 0 or occasion == 1)
    end
    # gp\ 0 (펞) ܂ 2 (j[̂) Ȃgp\
    return (occasion == 0 or occasion == 2)
  end
end

==> DQScriptsDemo_0_3_1.zip: DQScriptsDemo_0_3_1/rgss-lib/dq/item/rgss/Game_Party_initialize.rb <==
#==============================================================================
#  Game_Party_initialize.rb
#------------------------------------------------------------------------------
# p[eB̎͑܂Ƃ
# [IɃobNpbNiItem_InfinitỹReij
#==============================================================================

class Game_Party
  attr_reader :backpack

  #--------------------------------------------------------------------------
  #  IuWFNg
  #--------------------------------------------------------------------------
  alias dq_original_initialize initialize
  def initialize
    dq_original_initialize

    # obNpbN̍쐬
    @backpack = Game_Item.new
    @backpack.container = Item_Infinity_Container.new
    @backpack.container.add_stack_type(Game_Item)
  end

  #--------------------------------------------------------------------------
  #  ACȅ擾
  #     id : ACe ID
  #--------------------------------------------------------------------------
  def item_number(id,type=Game_Item)
    count = @backpack.item_count_id(id,type)
    actors.each do |actor|
      count += actor.backpack.item_count_id(id,type)
    end
    return count
  end

  #--------------------------------------------------------------------------
  #  ̏擾
  #     id :  ID
  #--------------------------------------------------------------------------
  def weapon_number(id)
    return item_number(id,Game_Weapon)
  end

  #--------------------------------------------------------------------------
  #  h̏擾
  #     id : h ID
  #--------------------------------------------------------------------------
  def armor_number(id)
    return item_number(id,Game_Armor)
  end

  #--------------------------------------------------------------------------
  #  ACȇ ()
  #     id : ACe ID
  #     n  : 
  #--------------------------------------------------------------------------
  def gain_item(id, n)
    Item_Facade.gain_item(id,n,self)
  end

  #--------------------------------------------------------------------------
  #  ̑ ()
  #     id :  ID
  #     n  : 
  #--------------------------------------------------------------------------
  def gain_weapon(id, n)
    Item_Facade.gain_weapon(id,n,self)
  end

  #--------------------------------------------------------------------------
  #  h̑ ()
  #     armor_id : h ID
  #     n        : 
  #--------------------------------------------------------------------------
  def gain_armor(id, n)
    Item_Facade.gain_armor(id,n,self)
  end

  #--------------------------------------------------------------------------
  #  ACě
  #     item_id : ACe ID
  #     n       : 
  #--------------------------------------------------------------------------
  def lose_item(item_id, n)
    # lt] gain_item Ă
    gain_item(item_id, -n)
  end

  #--------------------------------------------------------------------------
  #  ̌
  #     weapon_id :  ID
  #     n         : 
  #--------------------------------------------------------------------------
  def lose_weapon(weapon_id, n)
    # lt] gain_weapon Ă
    gain_weapon(weapon_id, -n)
  end

  #--------------------------------------------------------------------------
  #  ȟ
  #     armor_id : h ID
  #     n        : 
  #--------------------------------------------------------------------------
  def lose_armor(armor_id, n)
    # lt] gain_armor Ă
    gain_armor(armor_id, -n)
  end

  #--------------------------------------------------------------------------
  #  ACe̎gp\
  #     item_id : ACe ID
  #--------------------------------------------------------------------------
  def item_can_use?(item_id)
    # ACě 0 ̏ꍇ
    if item_number(item_id) == 0
      # gps\
      return false
    end
    # gp\擾
    occasion = $data_items[item_id].occasion
    # og̏ꍇ
    if $game_temp.in_battle
      # gp\ 0 (펞) ܂ 1 (oĝ) Ȃgp\
      return (occasion == 0 or occasion == 1)
    end
    # gp\ 0 (펞) ܂ 2 (j[̂) Ȃgp\
    return (occasion == 0 or occasion == 2)
  end
end
